@@ -72,10 +72,15 @@ find_percentiles <- function(repeats,
 # skewness ------------------------------------------------------------------
 
 fishers_skewness <- function(x, y) {
-  mean_val <- sum(x * y)
-  sd_val <- sqrt(sum(y * (x - mean_val)^2))
+  # Calculate the weighted mean
+  mean_val <- sum(x * y) / sum(y)
 
-  skewness <- sum(y * (x - mean_val)^3) / sd_val^3
+  # Calculate the weighted variance and standard deviation
+  variance <- sum(y * (x - mean_val)^2) / sum(y)
+  sd_val <- sqrt(variance)
+
+  # Calculate the weighted skewness
+  skewness <- sum(y * (x - mean_val)^3) / (sum(y) * sd_val^3)
 
   return(skewness)
 }
@@ -84,10 +89,16 @@ fishers_skewness <- function(x, y) {
 # kurtosis -----------------------------------------------------------------
 
 fishers_kurtosis <- function(x, y) {
-  mean_val <- sum(x * y)
-  sd_val <- sqrt(sum(y * (x - mean_val)^2))
+  # Calculate the weighted mean
+  mean_val <- sum(x * y) / sum(y)
+
+  # Calculate the weighted variance and standard deviation
+  variance <- sum(y * (x - mean_val)^2) / sum(y)
+  sd_val <- sqrt(variance)
+
+  # Calculate the weighted kurtosis
+  kurtosis <- (sum(y * (x - mean_val)^4) / (sum(y) * sd_val^4)) - 3
 
-  kurtosis <- (sum(y * (x - mean_val)^4) / sd_val^4) - 3
   return(kurtosis)
 }
 
@@ -126,13 +137,15 @@ repeat_table_subset <- function(repeat_table_df,
 
 #' Calculate Repeat Instability Metrics
 #'
-#' This function computes instability metrics from a list of fragments_repeats data objects.
+#' This function computes instability metrics from a list of fragments data objects.
 #'
-#' @param fragments_list A list of "fragments_repeats" objects representing fragment data.
-#' @param peak_threshold The threshold for peak signals to be considered in the calculations, relative to the modal peak signal of the expanded allele.
-#' @param window_around_index_peak A numeric vector (length = 2) defining the range around the index peak. First number specifies repeats before the index peak, second after. For example, \code{c(-5, 40)} around an index peak of 100 would analyze repeats 95 to 140. The sign of the numbers does not matter (The absolute value is found).
+#' @param fragments_list A list of "fragments" objects representing fragment data.
+#' @param peak_threshold A single numeric value between 0 and 1 for the threshold of peak signals to be considered in the calculations, relative to the modal peak signal of the expanded allele.
+#' @param window_around_index_peak A numeric vector (length 2) defining the range around the index peak. First number specifies repeats before the index peak, second after. For example, \code{c(-5, 40)} around an index peak of 100 would analyze repeats 95 to 140. The sign of the numbers does not matter (The absolute value is found).
 #' @param percentile_range A numeric vector of percentiles to compute (e.g., c(0.5, 0.75, 0.9, 0.95)).
 #' @param repeat_range A numeric vector specifying ranges of repeats for the inverse quantile computation.
+#' @param index_modal_signal_threshold A single numeric value for the minimum signal of the modal peak for the index samples (basically a quality control for the samples used to set the index peak or to calculate average_repeat_change or instability_index_change). This is only relevant when grouped = TRUE for the index peak assignment.
+#' @param index_signal_sum_threshold A single numeric value for the minimum sum of all peaks for each index sample (basically a quality control for the samples used to set the index peak or to calculate average_repeat_change or instability_index_change). This is only relevant when grouped = TRUE for the index peak assignment.
 #'
 #' @return A data.frame with calculated instability metrics for each sample.
 #' @details
@@ -147,11 +160,17 @@ repeat_table_subset <- function(repeat_table_df,
 #' - `QC_peak_number`: Quality control status based on the number of peaks (Low < 20, very low < 10).
 #' - `QC_off_scale`: Quality control comments for off-scale peaks. Potential peaks that are off-scale are given. However, a caveat is that this could be from any of the channels (ie it could be from the ladder channel but is the same scan as the given repeat).
 #'
+#' ## settings used
+#' - `peak_threshold`: THe peak_threshold parameter used.
+#' - `lower_repeat_threshold`: The lower repeat limit based of the index repeat of each sample.
+#' - `upper_repeat_threshold`: The upper repeat limit based of the index repeat of each sample.
+#' - `index_modal_signal_threshold`: The index_modal_signal_threshold parameter used.
+#' - `index_signal_sum_threshold`: The index_signal_sum_threshold parameter used.
+#'
 #' ## General sample metrics
 #' - `modal_peak_repeat`: The repeat size of the modal peak.
 #' - `modal_peak_signal`: The signal of the modal peak.
 #' - `index_peak_repeat`: The repeat size of the index peak (the repeat value closest to the modal peak of the index sample).
-#' - `index_peak_signal`: The signal of the index peak.
 #' - `index_weighted_mean_repeat`: The weighted mean repeat size (weighted on the signal of the peaks) of the index sample.
 #' - `n_peaks_total`: The total number of peaks in the repeat table.
 #' - `n_peaks_analysis_subset`: The number of peaks in the analysis subset.
@@ -162,6 +181,7 @@ repeat_table_subset <- function(repeat_table_df,
 #' - `weighted_mean_repeat`: The weighted mean repeat size (weight on peak signal) in the analysis subset.
 #' - `median_repeat`: The median repeat size in the analysis subset.
 #' - `max_signal`: The maximum peak signal in the analysis subset.
+#' - `sum_signal`: The sum of the peak signal in the analysis subset.
 #' - `max_delta_neg`: The maximum negative delta to the index peak.
 #' - `max_delta_pos`: The maximum positive delta to the index peak.
 #' - `skewness`: The skewness of the repeat size distribution.
@@ -170,7 +190,7 @@ repeat_table_subset <- function(repeat_table_df,
 #' ## Repeat instability metrics
 #' - `modal_repeat_change`: The difference between the modal repeat and the index repeat.
 #' - `average_repeat_change`: The weighted mean of the sample (weighted by peak signal) subtracted by the weighted mean repeat of the index sample(s).
-#' - `instability_index_change`: The instability index of the sample subtracted by the instability index of the index sample(s). This will be very similar to the average_repeat_change, with the key difference of instability_index_change being that it is an internally calculated metric for each sample, and therefore the random slight fluctuations of bp size (or systematic if across plates for example) will be removed. However, it requires the index peak to be correctly set for each sample, and if set incorrectly, can produce large arbitrary differences.  
+#' - `instability_index_change`: The instability index of the sample subtracted by the instability index of the index sample(s). This will be very similar to the average_repeat_change, with the key difference of instability_index_change being that it is an internally calculated metric for each sample, and therefore the random slight fluctuations of bp size (or systematic if across plates for example) will be removed. However, it requires the index peak to be correctly set for each sample, and if set incorrectly, can produce large arbitrary differences.
 #' - `instability_index`: The instability index based on peak signal and distance to the index peak. (See Lee et al., 2010, \doi{10.1186/1752-0509-4-29}).
 #' - `instability_index_abs`: The absolute instability index. The absolute value is taken for the "Change from the main allele".
 #' - `expansion_index`: The instability index for expansion peaks only.
@@ -183,67 +203,30 @@ repeat_table_subset <- function(repeat_table_df,
 #' @export
 #'
 #' @examples
-#' gm_raw <- trace::example_data
-#' metadata <- trace::metadata
+#' fsa_list <- lapply(cell_line_fsa_list, function(x) x$clone())
+#' # import data with read_fsa() to generate an equivalent list to cell_line_fsa_list
+#' test_fragments <- trace(fsa_list, grouped = TRUE, metadata_data.frame = metadata)
 #'
-#' test_fragments <- peak_table_to_fragments(gm_raw,
-#'   data_format = "genemapper5",
-#'   dye_channel = "B",
-#'   min_size_bp = 400
-#' )
-#'
-#' add_metadata(
-#'   fragments_list = test_fragments,
-#'   metadata_data.frame = metadata
-#' )
-#'
-#' find_alleles(
-#'   fragments_list = test_fragments,
-#'   peak_region_size_gap_threshold = 6,
-#'   peak_region_signal_threshold_multiplier = 1
-#' )
-#'
-#'
-#' call_repeats(
-#'   fragments_list = test_fragments,
-#'   assay_size_without_repeat = 87,
-#'   repeat_size = 3
-#' )
-#'
-#' assign_index_peaks(
-#'   fragments_list = test_fragments,
-#'   grouped = TRUE
-#' )
-#'
-#'
-#' # grouped metrics
-#' # uses t=0 samples as indicated in metadata
 #' test_metrics_grouped <- calculate_instability_metrics(
 #'   fragments_list = test_fragments,
 #'   peak_threshold = 0.05,
-#'   window_around_index_peak = c(-40, 40),
-#'   percentile_range = c(0.5, 0.75, 0.9, 0.95),
-#'   repeat_range = c(2, 5, 10, 20)
+#'   window_around_index_peak = c(-40, 40)
 #' )
 calculate_instability_metrics <- function(
     fragments_list,
     peak_threshold = 0.05,
-    window_around_index_peak = c(NA, NA),
+    window_around_index_peak = c(NA_real_, NA_real_),
     percentile_range = c(0.5, 0.75, 0.9, 0.95),
-    repeat_range = c(2, 5, 10, 20)) {
+    repeat_range = c(2, 5, 10, 20),
+    index_modal_signal_threshold = NA_real_,
+    index_signal_sum_threshold = NA_real_
+  ) {
+  # copy each object to make sure that they are not modified in place from this function
+  # want users to be able to rerun with index thresholds without having to rerun the whole pipeline
+  fragments_list <- lapply(fragments_list, function(x) x$clone())
+
   # calculate metrics
   metrics_list <- lapply(fragments_list, function(fragments_repeats) {
-    # check to make sure all the required steps for the function have been done
-    if(fragments_repeats$.__enclos_env__$private$find_main_peaks_used == FALSE){
-      stop(paste0(fragments_repeats$unique_id, " requires called alleles to calculate repeat instability metrics. Use 'find_alleles()'."),
-          call. = FALSE
-      )
-    } 
-    if(fragments_repeats$.__enclos_env__$private$assigned_index_peak_used == FALSE){
-      stop(paste0(fragments_repeats$unique_id, " requires an index peak to calculate repeat instability metrics. Use 'assign_index_peaks' to set the index peaks."),
-          call. = FALSE
-      )
-    } 
 
     # return early under different situations and record a reason why
     if (nrow(fragments_repeats$repeat_table_df) == 0) {
@@ -258,9 +241,7 @@ calculate_instability_metrics <- function(
       return(NULL)
     }
 
-    # no issues so set this as blank in case calculate_instability_metrics was run with an issue previously
-    fragments_repeats$.__enclos_env__$private$metrics_qc_message <- NA_character_
-
+    metrics_qc_message <- NA_character_
 
     # filter dataset to user supplied thresholds
     size_filtered_df <- repeat_table_subset(
@@ -272,51 +253,76 @@ calculate_instability_metrics <- function(
     )
 
     # filter and calculate index samples if they exist
+    index_weighted_mean_repeat <- NA
+    index_instability_index <- NA
     if(!is.null(fragments_repeats$.__enclos_env__$private$index_samples) && length(fragments_repeats$.__enclos_env__$private$index_samples) > 0){
 
       # filter for index samples with data
-      not_na_allele <- sapply(fragments_repeats$.__enclos_env__$private$index_samples, function(x) !is.na(x[[1]]))
-      index_sample_list_filtered <- fragments_repeats$.__enclos_env__$private$index_samples[not_na_allele]
 
-      if(length(index_sample_list_filtered) > 0){
-        index_sample_list_filtered <- lapply(index_sample_list_filtered, function(x){
-          list(
-            x[[1]],
-            repeat_table_subset(
-              repeat_table_df = x[[2]],
-              allele_signal = x[[2]][which(x[[2]]$repeats == x[[1]]), "signal"],
-              index_repeat = x[[1]],
-              peak_threshold = peak_threshold,
-              window_around_index_peak = window_around_index_peak
-            )
-          )
-        })
-  
-  
-        control_weighted_mean_repeat <- sapply(index_sample_list_filtered, function(x){
-          weighted.mean(x[[2]]$repeats, x[[2]]$signal)
-        })
-        index_weighted_mean_repeat <- median(control_weighted_mean_repeat, na.rm = TRUE)
-  
-        control_instability_index <- sapply(index_sample_list_filtered, function(x){
-          instability_index(
-            # can use the modal as the index peak since these are the index samples
-            repeats = x[[2]]$repeats,
-            signals = x[[2]]$signal,
-            index_peak_signal = x[[2]][which(x[[2]]$repeats == x[[1]]), "signal"],
-            index_peak_repeat = x[[1]],
+
+      not_na_allele <- sapply(fragments_repeats$.__enclos_env__$private$index_samples, function(x) !is.na(x$get_index_peak()$index_repeat))
+      index_sample_list_filtered <- fragments_repeats$.__enclos_env__$private$index_samples[not_na_allele]
+      index_table_list <- list()
+
+      if(length(index_sample_list_filtered) == 0){
+        metrics_qc_message <- "Index sample(s) do not have called alleles"
+      } else {
+        index_table_list <- lapply(index_sample_list_filtered, function(x){
+
+
+          df <- repeat_table_subset(
+            repeat_table_df = x$repeat_table_df,
+            allele_signal = x$get_allele_peak()$allele_signal, 
+            index_repeat = x$get_index_peak()$index_repeat,
             peak_threshold = peak_threshold,
-            abs_sum = FALSE
+            window_around_index_peak = window_around_index_peak
           )
+
+
+          index_peak_signal = x$repeat_table_df[which(x$repeat_table_df$repeats == x$get_index_peak()$index_repeat), "signal"]
+          index_peak_signal = ifelse(length(index_peak_signal) == 0, x$get_allele_peak()$allele_signal, index_peak_signal)
+
+          attr(df,"index_signal") <- index_peak_signal
+          attr(df,"allele_signal") <- x$get_allele_peak()$allele_signal
+          attr(df,"index_repeat") <- x$get_index_peak()$index_repeat
+
+          return(df)
         })
-        index_instability_index <- median(control_instability_index, na.rm = TRUE)
-      } else{
-        index_weighted_mean_repeat <- NA
-        index_instability_index <- NA
+
+        ## filter based on height and or signal sum
+        if(!is.na(index_modal_signal_threshold)){
+          above_signal_threshold <- sapply(index_table_list, function(x) attr(x,"index_signal") > index_modal_signal_threshold)
+          index_table_list <- index_table_list[above_signal_threshold]
+        }
+
+        if(!is.na(index_signal_sum_threshold)){
+          above_sum_threshold <- sapply(index_table_list, function(x) sum(x$signal) > index_signal_sum_threshold)
+          index_table_list <- index_table_list[above_sum_threshold]
+        }
+
+        # only continue if index samples survived the filtering
+        if(length(index_table_list) == 0){
+          metrics_qc_message <- "index threshold filter removed all index samples (therefore index peak assignment was also removed)"
+          fragments_repeats$set_index_peak(NA_real_)
+        } else{
+          control_weighted_mean_repeat <- sapply(index_table_list, function(x){
+            weighted.mean(x$repeats, x$signal)
+          })
+          index_weighted_mean_repeat <- median(control_weighted_mean_repeat, na.rm = TRUE)
+
+          control_instability_index <- sapply(index_table_list, function(x){
+            instability_index(
+              repeats = x$repeats,
+              signals = x$signal,
+              index_peak_signal = attr(x,"allele_signal"),
+              index_peak_repeat = attr(x,"index_repeat"),
+              peak_threshold = peak_threshold,
+              abs_sum = FALSE
+            )
+          })
+          index_instability_index <- median(control_instability_index, na.rm = TRUE)
+        }
       }
-    } else{
-      index_weighted_mean_repeat <- NA
-      index_instability_index <- NA
     }
 
     # first subset to make some dataframe that are just for contractions or expansions
@@ -353,14 +359,18 @@ calculate_instability_metrics <- function(
     # make a wide dataframe
     metrics <- data.frame(
       unique_id = fragments_repeats$unique_id,
-      QC_comments = NA_character_,
+      QC_comments = metrics_qc_message,
       QC_modal_peak_signal = QC_modal_peak_signal,
       QC_peak_number = QC_peak_number,
       QC_off_scale = QC_off_scale,
+      peak_threshold = peak_threshold,
+      lower_repeat_threshold = fragments_repeats$get_index_peak()$index_repeat - abs(window_around_index_peak[1]),
+      upper_repeat_threshold = fragments_repeats$get_index_peak()$index_repeat + abs(window_around_index_peak[2]),
+      index_modal_signal_threshold = index_modal_signal_threshold,
+      index_signal_sum_threshold = index_signal_sum_threshold,
       modal_peak_repeat = fragments_repeats$get_allele_peak()$allele_repeat,
       modal_peak_signal = fragments_repeats$get_allele_peak()$allele_signal,
       index_peak_repeat = fragments_repeats$get_index_peak()$index_repeat,
-      index_peak_signal = fragments_repeats$get_index_peak()$index_signal,
       index_weighted_mean_repeat = index_weighted_mean_repeat,
       n_peaks_total = nrow(fragments_repeats$repeat_table_df),
       n_peaks_analysis_subset = nrow(size_filtered_df),
@@ -371,6 +381,7 @@ calculate_instability_metrics <- function(
       weighted_mean_repeat = weighted.mean(size_filtered_df$repeats, size_filtered_df$signal),
       median_repeat = median(size_filtered_df$repeats),
       max_signal = max(size_filtered_df$signal),
+      sum_signal = sum(size_filtered_df$signal),
       max_delta_neg = min(size_filtered_df$repeat_delta_index_peak),
       max_delta_pos = max(size_filtered_df$repeat_delta_index_peak),
       skewness = fishers_skewness(size_filtered_df$repeats, size_filtered_df$signal),
@@ -417,7 +428,7 @@ calculate_instability_metrics <- function(
         peak_threshold = peak_threshold,
         abs_sum = FALSE
       ),
-      expansion_ratio = sum(expansion_filtered$peak_percent), 
+      expansion_ratio = sum(expansion_filtered$peak_percent),
       contraction_ratio = sum(contraction_filtered$peak_percent)
     )
 
@@ -441,7 +452,7 @@ calculate_instability_metrics <- function(
 
     metrics <- cbind(metrics, expansion_percentile)
     metrics <- cbind(metrics, expansion_repeat)
-        
+
     return(metrics)
   })
 
